@@ -1,4 +1,5 @@
 
+// Reply to a comment
 function reply_to(comment_id){
     var form_name = 'rt_form_'+comment_id;
     console.log(form_name);
@@ -13,11 +14,18 @@ function reply_to(comment_id){
     document.getElementById(form_name).style.display = 'block';
 }
 
+// Perform the like button action
+function sl_like(url, div_result){
+    var xhttp = new XMLHttpRequest();
+    xhttp.addEventListener("loadend", function(){
+        document.getElementById(div_result).innerHTML = this.responseText;
+    });
+    xhttp.open("GET", url, async=true);
+    xhttp.send();
+}
+
+// Invites the user to register at the site
 function log_2join(elm, url){
-    if (elm.value.length > 3 & !window.redirecting ) {
-        window.redirecting = true;
-        console.log(elm.value);
-        var current_url = window.location.href;
-        window.location = url + '?next=' + current_url;
-    }
+    var current_url = window.location.href;
+    window.location = url + '?next=' + current_url;
 }
